#include "LinearCurveEvaluator.h"

#include "CurveUtilities.h"

#include <assert.h>

void LinearCurveEvaluator::evaluateCurve(const std::vector<Point> & control_points, std::vector<Point> & evaluated_curve_points, const double & animation_time, const bool & wrap_control_points) const
{
	// this could be done with iterators too, of course

	unsigned int number_of_control_points			= control_points.size();

	evaluated_curve_points.clear();
	evaluated_curve_points.resize(number_of_control_points);

	for (unsigned int control_point_index = 0; control_point_index < number_of_control_points; ++control_point_index)
	{
		evaluated_curve_points[control_point_index] = control_points[control_point_index];
	}

	double x = 0.0;
	double y1;
	if ( wrap_control_points )
    {
		// if wrapping is on, I interpolate the y value at xmin and
		// xmax so that the slopes of the lines adjacent to the
		// wraparound are equal.

		y1 = ( control_points[0].y * (animation_time - control_points[number_of_control_points-1].x) + control_points[number_of_control_points-1].y * (control_points[0].x - 0.0) ) /
		     ( control_points[0].x - 0.0 + animation_time - control_points[number_of_control_points-1].x);
	}
	else
	{
		// if wrapping is off, I make the first and last segments of
		// the curve horizontal.

		y1 = control_points[0].y;
    }

	evaluated_curve_points.push_back(Point(x, y1));

	/// set the endpoint based on the wrap flag.
	double y2;
    x = animation_time;
    if ( wrap_control_points )
		y2 = y1;
    else
		y2 = control_points[number_of_control_points-1].y;

	evaluated_curve_points.push_back(Point(x, y2));
}

